==> ringcentral-widgets-0.12.0.tgz: package/components/CallingSettingsPanel/i18n/zh-CN.ts <==
import callingOptions from 'ringcentral-integration/modules/CallingSettings/callingOptions';
export default {
  title: "呼叫",
  [callingOptions.softphone]: "{brand}",
  [callingOptions.myphone]: "我的 {brand} 电话",
  [callingOptions.otherphone]: "其他电话",
  [callingOptions.customphone]: "自定义电话",
  [callingOptions.browser]: "浏览器",
  [callingOptions.jupiter]: "{brand}",
  makeCallsWith: "通过以下方式拨打电话",
  ringoutHint: "先在我的位置振铃，然后连接被叫方",
  myLocationLabel: "我的位置",
  press1ToStartCallLabel: "连接通话前提示我拨 1",
  [`${callingOptions.browser}Tooltip`]: "使用此选项通过计算机的麦克风和扬声器拨打和接听电话。",
  [`${callingOptions.softphone}Tooltip`]: "使用此选项，通过 {brand} 拨打和接听电话。",
  [`${callingOptions.myphone}Tooltip`]: "使用此选项通过您的 {brand} 电话拨打电话。",
  [`${callingOptions.myphone}Tooltip1`]: "对于您拨出的通话，您的 {brand} 电话会先振铃，然后您呼叫的对方电话再振铃。",
  [`${callingOptions.otherphone}Tooltip`]: "使用此选项通过您的其他电话拨打电话，例如，您在 {brand} 分机中添加的家庭电话或手机。",
  [`${callingOptions.otherphone}Tooltip1`]: "对于您拨出的通话，此电话会先振铃，然后您呼叫的对方电话再振铃。",
  [`${callingOptions.customphone}Tooltip`]: "使用此选项通过在下面的字段中输入有效的电话号码，使用您选择的任意电话拨打电话。",
  [`${callingOptions.customphone}Tooltip1`]: "对于您拨出的通话，此电话会先振铃，然后您呼叫的对方电话再振铃。",
  [`${callingOptions.jupiter}Tooltip`]: "使用此选项，通过 {brand} 拨打和接听电话。"
};

// @key: @#@"title"@#@ @source: @#@"Calling"@#@
// @key: @#@"[callingOptions.softphone]"@#@ @source: @#@"{brand}"@#@
// @key: @#@"[callingOptions.myphone]"@#@ @source: @#@"My {brand} Phone"@#@
// @key: @#@"[callingOptions.otherphone]"@#@ @source: @#@"Other Phone"@#@
// @key: @#@"[callingOptions.customphone]"@#@ @source: @#@"Custom Phone"@#@
// @key: @#@"[callingOptions.browser]"@#@ @source: @#@"Browser"@#@
// @key: @#@"[callingOptions.jupiter]"@#@ @source: @#@"{brand}"@#@
// @key: @#@"makeCallsWith"@#@ @source: @#@"Make my calls with"@#@
// @key: @#@"ringoutHint"@#@ @source: @#@"Ring me at my location first, then connect the called party"@#@
// @key: @#@"myLocationLabel"@#@ @source: @#@"My Location"@#@
// @key: @#@"press1ToStartCallLabel"@#@ @source: @#@"Prompt me to dial 1 before connecting the call"@#@
// @key: @#@"[`${callingOptions.browser}Tooltip`]"@#@ @source: @#@"Use this option to make and receive calls using your computer’s microphone and speaker."@#@
// @key: @#@"[`${callingOptions.softphone}Tooltip`]"@#@ @source: @#@"Use this option to make and receive calls using your {brand}."@#@
// @key: @#@"[`${callingOptions.myphone}Tooltip`]"@#@ @source: @#@"Use this option to make calls using your {brand} phone."@#@
// @key: @#@"[`${callingOptions.myphone}Tooltip1`]"@#@ @source: @#@"For the call you make, your {brand} phone will ring first then the party you called."@#@
// @key: @#@"[`${callingOptions.otherphone}Tooltip`]"@#@ @source: @#@"Use this option to make calls using your other phones such as home or cell phones that you have added in your {brand} Extension."@#@
// @key: @#@"[`${callingOptions.otherphone}Tooltip1`]"@#@ @source: @#@"For the call you make, this phone will ring first then the party you called."@#@
// @key: @#@"[`${callingOptions.customphone}Tooltip`]"@#@ @source: @#@"Use this option to make calls using any phone of your choice by entering a valid phone number in the field below."@#@
// @key: @#@"[`${callingOptions.customphone}Tooltip1`]"@#@ @source: @#@"For the call you make, this phone will ring first then the party you called."@#@
// @key: @#@"[`${callingOptions.jupiter}Tooltip`]"@#@ @source: @#@"Use this option to make and receive calls using your {brand}."@#@

==> ringcentral-widgets-0.12.4.tgz: package/components/CallingSettingsPanel/i18n/zh-CN.ts <==
import callingOptions from 'ringcentral-integration/modules/CallingSettings/callingOptions';
export default {
  title: "呼叫",
  [callingOptions.softphone]: "{brand} for Desktop",
  [callingOptions.browser]: "浏览器",
  [callingOptions.jupiter]: "{brand}",
  makeCallsWith: "通过以下方式拨打电话",
  ringoutHint: "先在我的位置振铃，然后连接被叫方",
  myLocationLabel: "我的位置",
  press1ToStartCallLabel: "连接通话前提示我拨 1",
  [`${callingOptions.browser}Tooltip`]: "使用此选项通过计算机的麦克风和扬声器拨打和接听电话。",
  [`${callingOptions.softphone}Tooltip`]: "使用此选项，通过 {brand} 拨打和接听电话。",
  [`${callingOptions.ringout}Tooltip`]: "通过此选项，可以使用您选择或输入的电话号码拨打电话。",
  [`${callingOptions.ringout}Tooltip1`]: "您拨打电话时，此电话会先响铃，然后被叫方再响铃。",
  [`${callingOptions.jupiter}Tooltip`]: "使用此选项，通过 {brand} 拨打和接听电话。"
};

// @key: @#@"title"@#@ @source: @#@"Calling"@#@
// @key: @#@"[callingOptions.softphone]"@#@ @source: @#@"{brand} for Desktop"@#@
// @key: @#@"[callingOptions.browser]"@#@ @source: @#@"Browser"@#@
// @key: @#@"[callingOptions.jupiter]"@#@ @source: @#@"{brand}"@#@
// @key: @#@"makeCallsWith"@#@ @source: @#@"Make my calls with"@#@
// @key: @#@"ringoutHint"@#@ @source: @#@"Ring me at my location first, then connect the called party"@#@
// @key: @#@"myLocationLabel"@#@ @source: @#@"My Location"@#@
// @key: @#@"press1ToStartCallLabel"@#@ @source: @#@"Prompt me to dial 1 before connecting the call"@#@
// @key: @#@"[`${callingOptions.browser}Tooltip`]"@#@ @source: @#@"Use this option to make and receive calls using your computer’s microphone and speaker."@#@
// @key: @#@"[`${callingOptions.softphone}Tooltip`]"@#@ @source: @#@"Use this option to make and receive calls using your {brand}."@#@
// @key: @#@"[`${callingOptions.ringout}Tooltip`]"@#@ @source: @#@"Use this option to make calls using your selected or entered phone number."@#@
// @key: @#@"[`${callingOptions.ringout}Tooltip1`]"@#@ @source: @#@"For the call you make, this phone will ring first then the party you called."@#@
// @key: @#@"[`${callingOptions.jupiter}Tooltip`]"@#@ @source: @#@"Use this option to make and receive calls using your {brand}."@#@
